@@ -63,33 +63,41 @@ class BaseHandler(tornado.web.RequestHandler):
 class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
                                tornado.auth.GoogleOAuth2Mixin):
     async def get(self):
-        log.write_logs("3. and 5.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        log.write_logs("3. and 5.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')    
-        self.authorize_redirect(
-            redirect_uri='http://grader-dev.data8x.berkeley.edu',
-            client_id=self.settings['google_oauth']['key'],
-            scope=["profile","email"],
-            response_type='code',
-            extra_params={'approval_prompt': 'auto'})
-
-class Userform(tornado.web.RequestHandler):
-    async def get(self):
-        log.write_logs("1a.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        log.write_logs("1b.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        if not self.get_argument('code', False) and not self.get_current_user():
-            log.write_logs("2.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-            self.redirect("/login")
-        elif self.get_argument('code', False):
+        log.write_logs("3. and 6.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        log.write_logs("3. and 6.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')    
+        if not self.get_argument('code', False):
             log.write_logs("4.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+            self.authorize_redirect(
+                redirect_uri='http://grader-dev.data8x.berkeley.edu',
+                client_id=self.settings['google_oauth']['key'],
+                scope=["profile","email"],
+                response_type='code',
+                extra_params={'approval_prompt': 'auto'})
+                
+        if not self.get_current_user():
             user = await self.get_authenticated_user(
                             redirect_uri='http://grader-dev.data8x.berkeley.edu',
                             code=self.get_argument('code'))
             # Save the user with e.g. set_secure_cookie
-            log.write_logs("5.", str(user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+            log.write_logs("6.", str(user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
             self.set_secure_cookie("user", user)
         
+class Userform(tornado.web.RequestHandler,
+                               tornado.auth.GoogleOAuth2Mixin):
+    async def get(self):
+        code = self.get_argument('code', False)
+        log.write_logs("1a.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        log.write_logs("1b.", str(code), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+        if not self.get_current_user():
+            log.write_logs("2, 5.", str(code), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+            red = "/login"
+            if code:
+                log.write_logs("5.", str(code), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+                red = f"{red}?code={code}"
+            self.redirect(red)
+        
         if self.get_current_user():
-            log.write_logs("6.", "Authenticated!", "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+            log.write_logs("7.", "Authenticated!", "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
             self.render("index.html",  message=None)
 
             
@@ -165,7 +173,10 @@ class Upload(tornado.web.RequestHandler):
         
 settings = {
     "cookie_secret": str(uuid.uuid4()),
-    "google_oauth" : {"key": "263483406093-5hfi9fqqp3a66hdpur9uu4fov701rjcq.apps.googleusercontent.com"}
+    "google_oauth" : {
+        "key": os.environ.get("OAUTH_CLIENT_ID"),
+        "secret": os.environ.get("OAUTH_SECRET")
+    }
 }
 application = tornado.web.Application([
         (r"/", Userform),
